@@ -215,18 +215,6 @@ class OpenEphysBase(object):
 		status = os.stat(path2file)
 		return status.st_size / ( 2.0 * n_channels * sample_rate)
 
-	def memmapBinaryFile(self, path2file:str, n_channels=384, **kwargs):
-		"""
-		Returns a numpy memmap of the 30Khz sampled high frequency data in the file
-		'continuous.dat', if present
-		"""
-		import os
-		if os.path.exists(path2file):
-			status = os.stat(path2file)
-			n_samples = status.st_size / ( 2.0 * n_channels )
-			mmap = np.memmap(path2file, np.int16, 'r', 0, (n_channels, n_samples), order='F')
-			return mmap
-
 	def prepareMaps(self, **kwargs):
 		"""Initialises a MapCalcsGeneric object by providing it with positional and
 		spiking data.
@@ -250,8 +238,8 @@ class OpenEphysBase(object):
 		xy, hdir = posProcessor.postprocesspos(self.settings.tracker_params)
 		self.hdir = hdir
 		spk_times = (self.kilodata.spk_times.T / 3e4)
-		if 'plot_type' in kwargs.keys():
-			plot_type = kwargs.pop('plot_type')
+		if 'plot_type' in kwargs:
+			plot_type = kwargs['plot_type']
 		else:
 			plot_type = 'map'
 		mapiter = MapCalcsGeneric(xy, np.squeeze(hdir), posProcessor.speed, self.xyTS, spk_times, plot_type, **kwargs)
@@ -267,92 +255,6 @@ class OpenEphysBase(object):
 		self.mapiter = mapiter
 		return mapiter
 
-	def plotMaps(self, **kwargs):
-		"""
-		Parameters
-		------------
-		plot_type : str or list
-			The type of map to plot. Valid strings include:
-			* 'map' - just ratemap plotted
-			* 'path' - just spikes on path
-			* 'both' - both of the above
-			* 'all' - both spikes on path, ratemap & SAC plotted
-		Valid kwargs: 'ppm' - this is an integer denoting pixels per metre:
-												lower values = more bins in ratemap / SAC
-				'cluster' - int or list of ints describing which clusters to plot
-		
-		Notes
-		-----
-		If providing a specific cluster or  list of clusters to this method with the keyword 
-		'cluster' then this is compared against the list of clusters from the Kilosort session.
-		Only clusters that are in both lists will be plotted.
-
-		Examples
-		--------
-		>>> from ephysiopy.openephys2py.OEKiloPhy import OpenEphysNPX
-		>>> npx = OpenEphysNPX('/path/to/data')
-		>>> npx.load()
-		>>> npx.plotMaps(plot_type='path', clusters=[1, 4, 6, 16, 22])
-
-		Will plot the spikes from clusters 1, 4, 6, 16, and 22 overlaid onto the xy position data 
-		in one figure window
-
-		"""
-		self.prepareMaps(**kwargs)
-		if 'clusters' in kwargs:
-			if type(kwargs['clusters']) == int:
-				self.mapiter.good_clusters = np.intersect1d([kwargs['clusters']], self.kilodata.good_clusters)
-
-			else:
-				self.mapiter.good_clusters = np.intersect1d(kwargs['clusters'], self.kilodata.good_clusters)
-		
-		self.mapiter.plotAll(**kwargs)
-
-	def plotMapsOneAtATime(self, plot_type='map', **kwargs):
-		"""
-		Parameters
-		----------
-		plot_type : str or list
-			The kind of plot to produce.  Valid strings include:
-			* 'map' - just ratemap plotted
-			* 'path' - just spikes on path
-			* 'both' - both of the above
-			* 'all' - both spikes on path, ratemap & SAC plotted
-		kwargs :
-		* 'ppm' - Integer denoting pixels per metre where lower values = more bins in ratemap / SAC
-		* 'clusters' - int or list of ints describing which clusters to plot
-		* 'save_grid_summary_location' - bool; if True the dictionary returned from gridcell.SAC.getMeasures is saved for each cluster
-		"""
-
-		if self.kilodata is None:
-			self.loadKilo(**kwargs)
-		if ( 'ppm' in kwargs.keys() ):
-			ppm = kwargs['ppm']
-		else:
-			ppm = 400
-		from ephysiopy.common.ephys_generic import PosCalcsGeneric, MapCalcsGeneric
-		if self.xy is None:
-
-			self.__loaddata__(**kwargs)
-		posProcessor = PosCalcsGeneric(self.xy[:,0], self.xy[:,1], ppm, jumpmax=self.jumpmax)
-		import os
-		self.__loadSettings__()
-		xy, hdir = posProcessor.postprocesspos(self.settings.tracker_params)
-		self.hdir = hdir
-		spk_times = (self.kilodata.spk_times.T / 3e4)
-		mapiter = MapCalcsGeneric(xy, np.squeeze(hdir), posProcessor.speed, self.xyTS, spk_times, plot_type, **kwargs)
-		if 'clusters' in kwargs:
-			if type(kwargs['clusters']) == int:
-				mapiter.good_clusters = np.intersect1d([kwargs['clusters']], self.kilodata.good_clusters)
-
-			else:
-				mapiter.good_clusters = np.intersect1d(kwargs['clusters'], self.kilodata.good_clusters)
-		else:
-			mapiter.good_clusters = self.kilodata.good_clusters
-		mapiter.spk_clusters = self.kilodata.spk_clusters
-		self.mapiter = mapiter
-		[ print("") for cluster in mapiter ]
-
 	def plotXCorrs(self, **kwargs):
 		if self.kilodata is None:
 			self.loadKilo(**kwargs)
@@ -407,6 +309,91 @@ class OpenEphysBase(object):
 			return ax, xy
 		return xy
 
+	def plotMaps(self, plot_type='map', **kwargs):
+		"""
+		Parameters
+		------------
+		plot_type : str or list
+			The type of map to plot. Valid strings include:
+			* 'map' - just ratemap plotted
+			* 'path' - just spikes on path
+			* 'both' - both of the above
+			* 'all' - both spikes on path, ratemap & SAC plotted
+		Valid kwargs: 'ppm' - this is an integer denoting pixels per metre:
+												lower values = more bins in ratemap / SAC
+				'cluster' - int or list of ints describing which clusters to plot
+		
+		Notes
+		-----
+		If providing a specific cluster or  list of clusters to this method with the keyword 
+		'cluster' then this is compared against the list of clusters from the Kilosort session.
+		Only clusters that are in both lists will be plotted.
+
+		Examples
+		--------
+		>>> from ephysiopy.openephys2py.OEKiloPhy import OpenEphysNPX
+		>>> npx = OpenEphysNPX('/path/to/data')
+		>>> npx.load()
+		>>> npx.plotMaps(plot_type='path', clusters=[1, 4, 6, 16, 22])
+
+		Will plot the spikes from clusters 1, 4, 6, 16, and 22 overlaid onto the xy position data 
+		in one figure window
+
+		"""
+		self.prepareMaps(**kwargs)
+		if 'clusters' in kwargs:
+			if type(kwargs['clusters']) == int:
+				self.mapiter.good_clusters = np.intersect1d([kwargs['clusters']], self.kilodata.good_clusters)
+
+			else:
+				self.mapiter.good_clusters = np.intersect1d(kwargs['clusters'], self.kilodata.good_clusters)
+		
+		self.mapiter.plotAll()
+
+	def plotMapsOneAtATime(self, plot_type='map', **kwargs):
+		"""
+		Parameters
+		----------
+		plot_type : str or list
+			The kind of plot to produce.  Valid strings include:
+			* 'map' - just ratemap plotted
+			* 'path' - just spikes on path
+			* 'both' - both of the above
+			* 'all' - both spikes on path, ratemap & SAC plotted
+		kwargs :
+		* 'ppm' - Integer denoting pixels per metre where lower values = more bins in ratemap / SAC
+		* 'clusters' - int or list of ints describing which clusters to plot
+		* 'save_grid_summary_location' - bool; if True the dictionary returned from gridcell.SAC.getMeasures is saved for each cluster
+		"""
+
+		if self.kilodata is None:
+			self.loadKilo(**kwargs)
+		if ( 'ppm' in kwargs.keys() ):
+			ppm = kwargs['ppm']
+		else:
+			ppm = 400
+		from ephysiopy.common.ephys_generic import PosCalcsGeneric, MapCalcsGeneric
+		if self.xy is None:
+			self.__loaddata__(**kwargs)
+		posProcessor = PosCalcsGeneric(self.xy[:,0], self.xy[:,1], ppm, jumpmax=self.jumpmax)
+		import os
+		self.__loadSettings__()
+		xy, hdir = posProcessor.postprocesspos(self.settings.tracker_params)
+		self.hdir = hdir
+		spk_times = (self.kilodata.spk_times.T / 3e4)
+		mapiter = MapCalcsGeneric(xy, np.squeeze(hdir), posProcessor.speed, self.xyTS, spk_times, plot_type, **kwargs)
+		if 'clusters' in kwargs:
+			if type(kwargs['clusters']) == int:
+				mapiter.good_clusters = np.intersect1d([kwargs['clusters']], self.kilodata.good_clusters)
+
+			else:
+				mapiter.good_clusters = np.intersect1d(kwargs['clusters'], self.kilodata.good_clusters)
+		else:
+			mapiter.good_clusters = self.kilodata.good_clusters
+		mapiter.spk_clusters = self.kilodata.spk_clusters
+		self.mapiter = mapiter
+		[ print("") for cluster in mapiter ]
+
 	def plotEEGPower(self, channel=0):
 		"""
 		Plots LFP power
@@ -515,7 +502,7 @@ class OpenEphysNPX(OpenEphysBase):
 		self.path2APdata = None
 		self.path2LFPdata = None
 
-	def load(self, pname_root=None, experiment_name='experiment1', recording_name='recording1', **kwargs):
+	def load(self, pname_root=None, experiment_name='experiment1', recording_name='recording1'):
 		"""
 		Loads data recorded in the OE 'flat' binary format.
 
@@ -677,9 +664,6 @@ class OpenEphysNPX(OpenEphysBase):
 		maxFreq : int
 			The maximum frequency in Hz to plot the spectrogram out to. Maximum 1250.
 			Default 125
-		kwargs: legal values are: 'frequencies' and 'channels'; both are lists that denote
-				which frequencies to show the mean power of along the length of the probe and,
-				which channels to show the frequency spectra of.
 		
 		Notes
 		-----
@@ -698,7 +682,6 @@ class OpenEphysNPX(OpenEphysBase):
 		from ephysiopy.common.ephys_generic import EEGCalcsGeneric
 		E = EEGCalcsGeneric(data[0, :], lfp_sample_rate)
 		E.calcEEGPowerSpectrum()
-		# Select a subset of the full amount of data to display later
 		spec_data = np.zeros(shape=(data.shape[0], len(E.sm_power[0::50])))
 		for chan in range(data.shape[0]):
 			E = EEGCalcsGeneric(data[chan, :], lfp_sample_rate)
@@ -710,16 +693,8 @@ class OpenEphysNPX(OpenEphysBase):
 		from matplotlib.pyplot import cm
 		from mpl_toolkits.axes_grid1 import make_axes_locatable
 		_, spectoAx = plt.subplots()
-		if 'cmap' in kwargs:
-			cmap = kwargs['cmap']
-		else:
-			cmap = 'bone'
-		spectoAx.pcolormesh(x, y, spec_data, edgecolors='face', cmap=cmap,norm=colors.LogNorm(), shading='nearest')
-		if 'minFreq' in kwargs:
-			minFreq = kwargs['minFreq']
-		else:
-			minFreq = 0
-		spectoAx.set_xlim(minFreq, maxFreq)
+		spectoAx.pcolormesh(x, y, spec_data, edgecolors='face', cmap='bone',norm=colors.LogNorm())
+		spectoAx.set_xlim(0, maxFreq)
 		spectoAx.set_ylim(channel_map[0], channel_map[-1])
 		spectoAx.set_xlabel('Frequency (Hz)')
 		spectoAx.set_ylabel('Channel')
@@ -729,13 +704,8 @@ class OpenEphysNPX(OpenEphysBase):
 		plt.setp(channel_spectoAx.get_xticklabels() + meanfreq_powerAx.get_yticklabels(), visible=False)
 
 		mn_power = np.mean(spec_data, 0)
-		if 'channels' in kwargs:
-			channels = kwargs['channels']
-			cols = iter(cm.rainbow(np.linspace(0,1,(len(kwargs['channels'])))))
-		else:
-			channels = np.arange(0, spec_data.shape[0], 60)
-			cols = iter(cm.rainbow(np.linspace(0,1,(nchannels//60)+1)))
-		for i in channels:
+		cols = iter(cm.rainbow(np.linspace(0,1,(nchannels//60)+1)))
+		for i in range(0, spec_data.shape[0], 60):
 			c = next(cols)
 			channel_spectoAx.plot(E.freqs[0::50], 10*np.log10(spec_data[i, :]/mn_power), c=c, label=str(i))
 
@@ -743,16 +713,9 @@ class OpenEphysNPX(OpenEphysBase):
 		channel_spectoAx.legend(bbox_to_anchor=(0., 1.02, 1., .102), loc='lower left', mode='expand',
 			fontsize='x-small', ncol=4)
 
-		if 'frequencies' in kwargs:
-			lower_freqs = kwargs['frequencies']
-			upper_freqs = lower_freqs[1::]
-			inc = np.diff([lower_freqs[-2],lower_freqs[-1]])
-			upper_freqs = np.append(upper_freqs, lower_freqs[-1]+inc)
-		else:
-			freq_inc = 6
-			lower_freqs = np.arange(1, maxFreq-freq_inc, freq_inc)
-			upper_freqs = np.arange(1+freq_inc, maxFreq, freq_inc)
-
+		freq_inc = 6
+		lower_freqs = np.arange(1, maxFreq-freq_inc, freq_inc)
+		upper_freqs = np.arange(1+freq_inc, maxFreq, freq_inc)
 		cols = iter(cm.nipy_spectral(np.linspace(0,1,len(upper_freqs))))
 		mn_power = np.mean(spec_data, 1)
 		for freqs in zip(lower_freqs, upper_freqs):
@@ -777,8 +740,8 @@ class OpenEphysNPX(OpenEphysBase):
 	def plotPos(self, jumpmax=None, show=True, **kwargs):
 		super().plotPos(jumpmax, show, **kwargs)
 
-	def plotMaps(self, **kwargs):
-		super().plotMaps(**kwargs)
+	def plotMaps(self, plot_type='map', **kwargs):
+		super().plotMaps(plot_type, **kwargs)
 
 	def plotMapsOneAtATime(self, plot_type='map', **kwargs):
 		super().plotMapsOneAtATime(plot_type, **kwargs)
@@ -877,15 +840,10 @@ class OpenEphysNWB(OpenEphysBase):
 			fpgaNode = 'processor' + str(fpgaId) + '_' + str(fpgaId)
 			self.ts = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['continuous'][fpgaNode]['timestamps'])
 			if (loadraw == True):
-				print("Attempting to reference ALL the raw data...")
-				self.rawData = self.nwbData['acquisition']['timeseries'][self.recording_name]['continuous'][fpgaNode]['data']
-				print("Referenced the raw data! Yay!\nParsing channels...")
+				self.rawData = np.array(self.nwbData['acquisition']['timeseries'][self.recording_name]['continuous'][fpgaNode]['data'])
 				self.settings.parseChannels() # to get the neural data channels
-				print("Channels parsed\nAccessing accelerometer data...")
 				self.accelerometerData = self.rawData[:,64:]
-				print("Accessed the accelerometer data\nAttempting to access the raw data...")
 				self.rawData = self.rawData[:,0:64]
-				print("Got the raw data!")
 				if (savedat == True):
 					data2save = self.rawData[:,0:64]
 					data2save.tofile(os.path.join(pname_root, 'experiment_1.dat'))
@@ -925,8 +883,8 @@ class OpenEphysNWB(OpenEphysBase):
 		xy = super().plotPos(jumpmax, show)
 		return xy
 
-	def plotMaps(self, **kwargs):
-		super().plotMaps(**kwargs)
+	def plotMaps(self, plot_type='map', **kwargs):
+		super().plotMaps(plot_type, **kwargs)
 
 	def plotMapsOneAtATime(self, plot_type='map', **kwargs):
 		super().plotMapsOneAtATime(plot_type, **kwargs)
@@ -1002,18 +960,15 @@ class OpenEphysBinary(OpenEphysBase):
 			self.xyTS = pos_ts / 30.0 / 1000.0
 
 		ap_sample_rate = 30000
-		if os.path.exists(os.path.join(self.path2APdata, 'continuous.dat')):
-			trial_length = self.__calcTrialLengthFromBinarySize__(os.path.join(self.path2APdata, 'continuous.dat'), n_channels, ap_sample_rate)
+		trial_length = self.__calcTrialLengthFromBinarySize__(os.path.join(self.path2APdata, 'continuous.dat'), n_channels, ap_sample_rate)
 		
 		if loadraw:
-			if os.path.exists(os.path.join(self.path2APdata, 'continuous.dat')):
-				status = os.stat(os.path.join(self.path2APdata, 'continuous.dat'))
-				n_samples = int(status.st_size / 2/ n_channels)
-				mmap = np.memmap(os.path.join(self.path2APdata, 'continuous.dat'), np.int16, 'r', 0, (n_channels, n_samples), 'C')
-				self.rawData = np.array(mmap, dtype=np.float64)
+			status = os.stat(os.path.join(self.path2APdata, 'continuous.dat'))
+			n_samples = int(status.st_size / 2/ n_channels)
+			mmap = np.memmap(os.path.join(self.path2APdata, 'continuous.dat'), np.int16, 'r', 0, (n_channels, n_samples), 'C')
+			self.rawData = np.array(mmap, dtype=np.float64)
 		
 		# Load the start time from the sync_messages file
-		recording_start_time = 0
 		if sync_message_file is not None:
 			with open(sync_message_file, 'r') as f:
 				sync_strs = f.read()
@@ -1024,7 +979,7 @@ class OpenEphysBinary(OpenEphysBase):
 					start_val = line[idx + len('start time: '):-1]
 					tmp = start_val.split('@')
 					recording_start_time = float(tmp[0]) / float(tmp[1][0:-1])
-			self.xyTS = self.xyTS - recording_start_time # ensure pos timestamps are zeroed
+			self.xyTS = self.xyTS - self.recording_start_time # ensure pos timestamps are zeroed
 		else:
 			recording_start_time = self.xyTS[0]
 		self.recording_start_time = recording_start_time
@@ -1059,8 +1014,8 @@ class OpenEphysBinary(OpenEphysBase):
 		xy = super().plotPos(jumpmax, show)
 		return xy
 
-	def plotMaps(self, **kwargs):
-		super().plotMaps(**kwargs)
+	def plotMaps(self, plot_type='map', **kwargs):
+		super().plotMaps(plot_type, **kwargs)
 
 	def plotMapsOneAtATime(self, plot_type='map', **kwargs):
 		super().plotMapsOneAtATime(plot_type, **kwargs)
